reqctx

package
v0.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 2, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetRequestID

func GetRequestID(ctx context.Context) string

GetRequestID returns the request ID from the context, or "" if absent.

func GetWorkspace

func GetWorkspace(ctx context.Context) models.WorkspaceID

GetWorkspace returns the workspace ID from the context, or "" if absent.

func WithRequestID

func WithRequestID(ctx context.Context, id string) context.Context

WithRequestID returns a context carrying the given request ID.

func WithWorkspace

func WithWorkspace(ctx context.Context, id models.WorkspaceID) context.Context

WithWorkspace returns a context carrying the given workspace ID.

Types

This section is empty.

Jump to