Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetRequestID ¶
GetRequestID returns the request ID from the context, or "" if absent.
func GetWorkspace ¶
func GetWorkspace(ctx context.Context) models.WorkspaceID
GetWorkspace returns the workspace ID from the context, or "" if absent.
func WithRequestID ¶
WithRequestID returns a context carrying the given request ID.
func WithWorkspace ¶
WithWorkspace returns a context carrying the given workspace ID.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.